import * as d3 from 'd3'
import { DataloadValueDetail } from 'models'
import React, { useEffect, useRef } from 'react'
import './totalAnalysisChart.scss'

interface PieProps {
  innerRadius: number
  outerRadius: number
  dataloadValueDetailArray: DataloadValueDetail[]
  radius: number
  children: React.ReactNode
}

const PieChart = ({
  innerRadius,
  outerRadius,
  dataloadValueDetailArray,
  radius,
  children,
}: PieProps) => {
  const ref = useRef(null)
  const createPie = d3.pie().sort(null)
  const arcWidth = outerRadius - innerRadius

  useEffect(() => {
    const dataloadArray = dataloadValueDetailArray.map(
      dataload => dataload.value
    )
    const data = createPie(dataloadArray)
    const group = d3.select(ref.current)
    const groupWithData = group.selectAll('g.arc').data(data)
    const colors = ['#D87B39', '#3A98EC', '#45D1B8']

    const createArc: any = d3
      .arc()
      .innerRadius(innerRadius)
      .outerRadius(outerRadius)
    groupWithData.exit().remove()

    const groupWithUpdate = groupWithData
      .enter()
      .append('g')
      .attr('class', 'arc')
      .attr('filter', 'url(#glow)')

    const path = groupWithUpdate
      .append('path')
      .merge(groupWithData.select('path.arc'))

    path
      .attr('class', 'arc')
      .attr('d', createArc)
      .attr('fill', (_d, i) => colors[i])
  }, [createPie, dataloadValueDetailArray, innerRadius, outerRadius])

  return (
    <div
      className="pie-container"
      style={{
        width: radius,
        height: radius,
      }}
    >
      <svg width={radius} height={radius}>
        <defs>
          <filter id="glow" height="300%" width="300%" x="-75%" y="-75%">
            <feGaussianBlur stdDeviation="10" result="coloredBlur" />
            <feMerge>
              <feMergeNode in="coloredBlur" />
              <feMergeNode in="SourceGraphic" />
            </feMerge>
          </filter>
        </defs>
        <g ref={ref} transform={`translate(${outerRadius} ${outerRadius})`} />
      </svg>
      <div
        className="pie-center"
        style={{
          width: radius - arcWidth,
          height: radius - arcWidth,
          top: arcWidth / 2,
          left: arcWidth - arcWidth / 2,
        }}
      >
        {children}
        <div
          className="circle"
          style={{
            width: radius - arcWidth * 2,
            height: radius - arcWidth * 2,
            top: arcWidth / 2,
            left: arcWidth - arcWidth / 2,
          }}
        />
      </div>
    </div>
  )
}

export default PieChart
