import { act, render } from '@testing-library/react'
import React from 'react'
import { BrowserRouter as Router } from 'react-router-dom'
import usePageTitle from './usePageTitle'

const TestComponent = () => {
  usePageTitle()
  return null
}

const setLocation = (pathname: string) => {
  render(
    <Router>
      <TestComponent />
    </Router>
  )
  window.history.pushState({}, '', pathname)
}

describe('usePageTitle hook', () => {
  beforeEach(() => {
    document.title = ''
  })

  const cases = [
    { pathname: '/consumption', expected: 'Conso | Ecolyo' },
    {
      pathname: '/ecogesture-selection',
      expected: 'Sélection des astuces | Ecolyo',
    },
    { pathname: '/ecogesture-form', expected: 'Astuces | Ecolyo' },
    { pathname: '/ecogestures', expected: 'Astuces | Ecolyo' },
    { pathname: '/options', expected: 'Options | Ecolyo' },
    { pathname: '/options/legalnotice', expected: 'Mentions Légales | Ecolyo' },
    {
      pathname: '/options/gcu',
      expected: "Conditions Générales d'Utilisation | Ecolyo",
    },
    { pathname: '/analysis', expected: 'Analyse | Ecolyo' },
    { pathname: '/profileType', expected: 'Ajuster mon profil | Ecolyo' },
    { pathname: '/challenges', expected: 'Défis | Ecolyo' },
    { pathname: '/challenges/duel', expected: 'Défis | Ecolyo' },
    {
      pathname: '/consumption/electricity',
      expected: 'Conso électrique | Ecolyo',
    },
    { pathname: '/connect/electricity', expected: 'Conso électrique | Ecolyo' },
    { pathname: '/consumption/water', expected: "Conso d'eau | Ecolyo" },
    { pathname: '/consumption/gas', expected: 'Conso de gaz | Ecolyo' },
    { pathname: '/connect/gas', expected: 'Conso de gaz | Ecolyo' },
  ]

  test.each(cases)('sets the title for $pathname', ({ pathname, expected }) => {
    act(() => {
      setLocation(pathname)
    })
    expect(document.title).toBe(expected)
  })
})
