import { QueryResult } from 'cozy-client'
import profileTypeDataJson from 'db/profileTypeData.json'
import { DateTime } from 'luxon'
import { ProfileType } from 'models'
import mockClient from 'tests/__mocks__/client.mock'
import { profileTypeData } from 'tests/__mocks__/profileType.mock'
import ProfileTypeEntityService from './profileTypeEntity.service'

describe('UserProfileTypeEntity service', () => {
  const pteService = new ProfileTypeEntityService(mockClient)

  describe('getUserProfileType', () => {
    const mockProfileQueryResult: QueryResult<ProfileType[]> = {
      data: [profileTypeData],
      bookmark: '',
      next: false,
      skip: 0,
    }
    const mockEmptyQueryResult: QueryResult<ProfileType[]> = {
      data: [],
      bookmark: '',
      next: false,
      skip: 0,
    }
    it('should return the closest profileType according to passed argument updateDate', async () => {
      mockClient.query.mockResolvedValueOnce(mockProfileQueryResult)
      const result = await pteService.getProfileType(DateTime.local(2022, 1, 1))
      expect(result).toEqual(profileTypeData)
    })

    it('should not find a profile corresponding to the passed argument updateDate', async () => {
      mockClient.query.mockResolvedValueOnce(mockEmptyQueryResult)
      mockClient.query.mockResolvedValueOnce(mockProfileQueryResult)
      const result = await pteService.getProfileType(DateTime.local(2022, 1, 1))
      expect(result).toEqual(profileTypeData)
    })

    it('should return default profileType if no profile found when date is given', async () => {
      const date = DateTime.local(2022, 1, 1)
      const defaultProfileType = {
        ...profileTypeDataJson[0].profileType,
        updateDate: date,
      } as ProfileType

      mockClient.query.mockResolvedValueOnce(mockEmptyQueryResult)
      mockClient.query.mockResolvedValueOnce(mockEmptyQueryResult)
      const result = await pteService.getProfileType(date)
      expect(result).toEqual(defaultProfileType)
    })
    it('should return the last profileType in base', async () => {
      mockClient.query.mockResolvedValueOnce(mockProfileQueryResult)
      const result = await pteService.getProfileType()
      expect(result).toEqual(profileTypeData)
    })

    it('should return null if no user profile found', async () => {
      mockClient.query.mockResolvedValueOnce(mockEmptyQueryResult)
      const result = await pteService.getProfileType()
      expect(result).toBeNull()
    })
  })
})
